diff --git a/src/modules/locale/GeoIPTests.cpp b/src/modules/locale/GeoIPTests.cpp
index 32faf7138..a98aa25ee 100644
--- a/src/modules/locale/GeoIPTests.cpp
+++ b/src/modules/locale/GeoIPTests.cpp
@@ -127,14 +127,14 @@ void
GeoIPTests::testXML2()
{
static const char data[] =
- "America/North Dakota/Beulah";
+ "America/North Dakota/Beulah"; // With a space!
#ifdef HAVE_XML
GeoIPXML handler;
auto tz = handler.processReply( data );
QCOMPARE( tz.first, QLatin1String( "America" ) );
- QCOMPARE( tz.second, QLatin1String( "North Dakota/Beulah" ) );
+ QCOMPARE( tz.second, QLatin1String( "North_Dakota/Beulah" ) ); // Without space
#endif
}
@@ -184,10 +184,10 @@ void GeoIPTests::testSplitTZ()
tz = GeoIP::splitTZString( QLatin1String("America.NewYork") );
QCOMPARE( tz.first, QString() );
// Check that three-level is split properly
tz = GeoIP::splitTZString( QLatin1String("America/North Dakota/Beulah") );
QCOMPARE( tz.first, QLatin1String("America") );
- QCOMPARE( tz.second, QLatin1String("North Dakota/Beulah") );
+ QCOMPARE( tz.second, QLatin1String("North_Dakota/Beulah") );
}
@@ -184,10 +184,10 @@ void GeoIPTests::testSplitTZ()
tz = GeoIP::splitTZString( QLatin1String("America.NewYork") );
QCOMPARE( tz.first, QString() );
- // Check that three-level is split properly
+ // Check that three-level is split properly and space is replaced
tz = GeoIP::splitTZString( QLatin1String("America/North Dakota/Beulah") );
QCOMPARE( tz.first, QLatin1String("America") );